function [rows,columns] = getMKLDataArea(XLSData)
%GETMKLDATAAREA  get the area in the xls where to find data.
%
%   More data is read form the xls then is really needed. This function
%   finds the area where the data is really found. It is specific for the
%   MKLall  xls sheet.
%
%   Syntax:
%   [rows,columns] = getMKLDataArea(XLSData)
%
%   Input:
%   XLSData = the raw data from an XLS-sheet
%
%   Output:
%   rows    = the rows for the data area
%   columns = the column range of the data area
%
%   Example
%   ..
%
%   See also 

%% Copyright notice
%   --------------------------------------------------------------------
%   Copyright (C) 2010 <COMPANY>
%       Lou Verhage
%
%       <EMAIL>	
%
%       <ADDRESS>
%
%   This library is free software: you can redistribute it and/or
%   modify it under the terms of the GNU Lesser General Public
%   License as published by the Free Software Foundation, either
%   version 2.1 of the License, or (at your option) any later version.
%
%   This library is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%   Lesser General Public License for more details.
%
%   You should have received a copy of the GNU Lesser General Public
%   License along with this library. If not, see <http://www.gnu.org/licenses/>.
%   --------------------------------------------------------------------

% This tool is part of <a href="http://OpenEarth.nl">OpenEarthTools</a>.
% OpenEarthTools is an online collaboration to share and manage data and 
% programming tools in an open source, version controlled environment.
% Sign up to recieve regular updates of this function, and to contribute 
% your own tools.

%% Version <http://svnbook.red-bean.com/en/1.5/svn.advanced.props.special.keywords.html>
% Created: 01 Mar 2010
% Created with Matlab version: 7.8.0.347 (R2009a)

% $Id: getMKLDataArea.m 1120 2010-03-22 11:53:59Z verhage $
% $Date: 2010-03-22 12:53:59 +0100 (Mon, 22 Mar 2010) $
% $Author: verhage $
% $Revision: 1120 $
% $HeadURL: https://svn.oss.deltares.nl/repos/openearthrawdata/trunk/rijkswaterstaat/kustlijnkaartenboek/scripts/getMKLDataArea.m $
% $Keywords: $

%%
rows(1) = 3;
n       = 3;
while (true)
    n = n + 1;
    if isnan(XLSData{n,1})
        rows(2) = n - 1;
        break
    end
end

columns(1) = 3;
n          = 3;
while (true)
    n = n + 1;
    if isnan(XLSData{1,n})
        columns(2) = n - 1;
        break
    end
end


